Crate trapdoor

Crate trapdoor 

Data structure that accumulates data in separate cells which allows for minimal (I think?) friction between taking accumulated data while storing new data continuously.

Structs

Trapdoor
A trapdoor.